@@ -625,7 +625,7 @@ def get_loan_pmt(
     loan_amt: float,
     period: float,
     term: float,
-    gr: Union[float, Rate],
+    gr: Union[float, Rate, TieredTime],
     imd: str = 'immediate',
     gprog: float = 0.0,
     aprog: float = 0.0,
@@ -662,12 +662,27 @@ def get_loan_pmt(
         term=term,
         gr=gr,
         gprog=gprog,
-        aprog=aprog,
         imd=imd
     )
 
-    pmt = loan_amt / ann.pv()
-    pmts = [pmt * x for x in ann.amounts]
+    if aprog >= 0:
+        i = ann.gr.effective_interval(t2=ann.period)
+        n = ann.n_payments
+        v = ann.gr.discount_func(period)
+        pmt = (loan_amt - (aprog / i) * (ann.pv() - n * v ** n)) / (ann.pv())
+        iann = Annuity(
+            amount=pmt,
+            period=period,
+            term=term,
+            gr=gr,
+            aprog=aprog,
+            imd=imd
+        )
+        pmts = iann.amounts
+    else:
+        pmt = loan_amt / ann.pv()
+        pmts = [pmt * x for x in ann.amounts]
+
     times = ann.times
 
     pmts_dict = {
@@ -687,7 +702,6 @@ def get_loan_pmt(
             term=term,
             gr=gr,
             gprog=gprog,
-            aprog=aprog,
             imd=imd
         ).pv()
 
@@ -712,14 +726,15 @@ def get_loan_pmt(
                 term=term,
                 gr=gr,
                 gprog=gprog,
+                aprog=aprog,
                 imd=imd
             )
 
             diff = d_ann.pv() - loan_amt
 
-            last_pmt = d_ann.amounts[-1] - round(diff * acc.val(t=term), 2)
+            last_pmt = round(d_ann.amounts[-1] - round(diff * acc.val(t=term), 2), 2)
 
-            pmts = [pmt_round2 * x for x in ann.amounts[:-1]]
+            pmts = [round(x, 2) for x in d_ann.amounts[:-1]]
             pmts.append(last_pmt)
 
             pmts_dict = {
@@ -734,7 +749,7 @@ def get_savings_pmt(
     fv: float,
     period: float,
     term: float,
-    gr: Rate,
+    gr: Union[float, Rate],
     cents=False
 ) -> Union[float, tuple]:
     """
@@ -1006,3 +1021,20 @@ def get_perpetuity_pmt(
     amount = i * pv
 
     return amount
+
+
+def n_solver(
+        gr,
+        amount,
+        sv=None,
+        period=None,
+):
+    if sv:
+        acc = standardize_acc(gr)
+        i = acc.effective_rate(period)
+
+        n = np.log(1 + sv / amount * i) / np.log(1 + i)
+    else:
+        n = None
+
+    return n
