@@ -8,8 +8,10 @@ import datetime as dt
 import numpy as np
 
 from inspect import signature
+from numpy import ndarray
 from scipy.misc import derivative
-from typing import Callable, Union
+from scipy.optimize import newton
+from typing import Callable, Iterable, Union
 
 from tmval.constants import COMPOUNDS, SIMPLES
 from tmval.rate import Rate, standardize_rate
@@ -266,6 +268,30 @@ class Amount:
         accumulation = Accumulation(gr=acc_func)
         return accumulation
 
+    def solve_t(self, fv, pv=None, x0=range(100), precision=5):
+
+        if pv is None:
+            t0 = 0
+        else:
+            def f0(t):
+                return pv - self.val(t)
+            rs = newton(f0, x0=x0)
+            if isinstance(rs, Iterable):
+                t0 = list(set([round(x, precision) for x in rs]))[0]
+            else:
+                t0 = rs
+
+        def f1(t):
+            return fv - self.val(t)
+
+        rs = newton(f1, x0=x0)
+        if isinstance(rs, Iterable):
+            t1 = list(set([round(x, precision) for x in rs]))[0]
+        else:
+            t1 = rs
+
+        return t1 - t0
+
 
 class Accumulation(Amount):
     """
@@ -385,6 +411,21 @@ class Accumulation(Amount):
 
         return delta_t
 
+    def solve_t(self, pv, fv, x0=10):
+
+        def f(t0):
+            return self.val(t0) - fv / pv
+
+        roots = newton(func=f, x0=x0)
+        if isinstance(roots, ndarray):
+            pass
+        else:
+            roots = np.array(roots)
+        reals = roots[np.isreal(roots)]
+        res = round(reals[0])
+
+        return res
+
 
 def simple_solver(
     pv: float = None,
@@ -924,3 +965,31 @@ def read_iym(
     rate = Rate(rate)
 
     return rate
+
+
+def invsec(amt1: Amount, amt2: Amount, x0=range(100), precision=5) -> list:
+    """
+    Finds the point(s) at which two accumulation functions intersect.
+
+    :param amt1:
+    :type amt1:
+    :param amt2:
+    :type amt2:
+    :param x0:
+    :type x0:
+    :param precision:
+    :type precision:
+    :return:
+    :rtype:
+    """
+    def f(t):
+        return amt1.val(t) - amt2.val(t)
+
+    sol = newton(f, x0=x0)
+
+    sol = [round(x, precision) for x in sol]
+
+    res = list(set(sol))
+
+    return res
+
